# guietta

A tool for making simple Python GUIs

Guietta is a tool that makes simple GUIs *simple*:

![Example code](http://guietta.com/_images/example_code.png)

And here it is:

![Example GUI](http://guietta.com/_images/example.png)


# Installation

 **pip install guietta**
 

If you use conda, please read our page on
[QT incompatibilities with conda](https://guietta.readthedocs.io/en/latest/qt_conda.html).


# Documentation

https://guietta.readthedocs.io/en/latest/